@@ -7,5 +7,5 @@ if [ -x /sbin/ldconfig ]; then
 fi
 
 if [ -x ${PREFIX}/bin/safe_mysqld ]; then
- ${PREFIX}/bin/safe_mysqld --user="mysql" > /dev/null & echo -n ' mysql'
+ ${PREFIX}/bin/safe_mysqld > /dev/null & echo -n ' mysql'
 fi
